"""empty message

Revision ID: f46112e923d8
Revises:
Create Date: 2023-02-27 09:43:42.498907

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "f46112e923d8"
down_revision = None
branch_labels = None
depends_on = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table(
        "users",
        sa.Column("id", sa.Integer(), nullable=False),
        sa.Column("first_name", sa.String(length=16), nullable=False),
        sa.Column("middle_name", sa.String(length=16), nullable=True),
        sa.Column("last_name", sa.String(length=16), nullable=False),
        sa.PrimaryKeyConstraint("id"),
    )
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_table("users")
    # ### end Alembic commands ###
